MenuNode class

Implemented types

Constructors

const
factory

Properties

children List<MenuNode>
final
data MenuMeta
final
depth int
final
hashCode int
The hash code for this object.
no setterinherited
id String
no setteroverride
isLeaf bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(String id) MenuNode?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryMenuNodeByPath(MenuNode node, String id) MenuNode?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited