DropMenuCellStyle class
Constructors
- DropMenuCellStyle({required Color backgroundColor, required Color disableColor, required Color foregroundColor, required Color hoverForegroundColor, required Color hoverBackgroundColor, EdgeInsetsGeometry? padding, BorderRadius? borderRadius, TextStyle? textStyle})
-
const
- DropMenuCellStyle.dark()
-
factory
- DropMenuCellStyle.light()
-
factory
Properties
- backgroundColor → Color
-
final
- borderRadius → BorderRadius?
-
final
- disableColor → Color
-
final
- foregroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverBackgroundColor → Color
-
final
- hoverForegroundColor → Color
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited